import pyeccodes.accessors as _


def load(h):

    def wrapped(h):

        table2Version = h.get_l('table2Version')
        indicatorOfParameter = h.get_l('indicatorOfParameter')

        if table2Version == 203 and indicatorOfParameter == 255:
            return 255

        if table2Version == 203 and indicatorOfParameter == 254:
            return 254

        if table2Version == 203 and indicatorOfParameter == 253:
            return 253

        if table2Version == 203 and indicatorOfParameter == 252:
            return 252

        if table2Version == 203 and indicatorOfParameter == 251:
            return 251

        if table2Version == 203 and indicatorOfParameter == 250:
            return 250

        if table2Version == 203 and indicatorOfParameter == 249:
            return 249

        if table2Version == 203 and indicatorOfParameter == 248:
            return 248

        if table2Version == 203 and indicatorOfParameter == 247:
            return 247

        if table2Version == 203 and indicatorOfParameter == 246:
            return 246

        if table2Version == 203 and indicatorOfParameter == 245:
            return 245

        if table2Version == 203 and indicatorOfParameter == 244:
            return 244

        if table2Version == 203 and indicatorOfParameter == 243:
            return 243

        if table2Version == 203 and indicatorOfParameter == 242:
            return 242

        if table2Version == 203 and indicatorOfParameter == 241:
            return 241

        if table2Version == 203 and indicatorOfParameter == 240:
            return 240

        if table2Version == 203 and indicatorOfParameter == 239:
            return 239

        if table2Version == 203 and indicatorOfParameter == 238:
            return 238

        if table2Version == 203 and indicatorOfParameter == 237:
            return 237

        if table2Version == 203 and indicatorOfParameter == 236:
            return 236

        if table2Version == 203 and indicatorOfParameter == 235:
            return 235

        if table2Version == 203 and indicatorOfParameter == 234:
            return 234

        if table2Version == 203 and indicatorOfParameter == 233:
            return 233

        if table2Version == 203 and indicatorOfParameter == 232:
            return 232

        if table2Version == 203 and indicatorOfParameter == 231:
            return 231

        if table2Version == 203 and indicatorOfParameter == 230:
            return 230

        if table2Version == 203 and indicatorOfParameter == 229:
            return 229

        if table2Version == 203 and indicatorOfParameter == 228:
            return 228

        if table2Version == 203 and indicatorOfParameter == 227:
            return 227

        if table2Version == 203 and indicatorOfParameter == 226:
            return 226

        if table2Version == 203 and indicatorOfParameter == 225:
            return 225

        if table2Version == 203 and indicatorOfParameter == 224:
            return 224

        if table2Version == 203 and indicatorOfParameter == 223:
            return 223

        if table2Version == 203 and indicatorOfParameter == 222:
            return 222

        if table2Version == 203 and indicatorOfParameter == 221:
            return 221

        if table2Version == 203 and indicatorOfParameter == 220:
            return 220

        if table2Version == 203 and indicatorOfParameter == 219:
            return 219

        if table2Version == 203 and indicatorOfParameter == 218:
            return 218

        if table2Version == 203 and indicatorOfParameter == 217:
            return 217

        if table2Version == 203 and indicatorOfParameter == 216:
            return 216

        if table2Version == 203 and indicatorOfParameter == 215:
            return 215

        if table2Version == 203 and indicatorOfParameter == 214:
            return 214

        if table2Version == 203 and indicatorOfParameter == 213:
            return 213

        if table2Version == 203 and indicatorOfParameter == 212:
            return 212

        if table2Version == 203 and indicatorOfParameter == 211:
            return 211

        if table2Version == 203 and indicatorOfParameter == 210:
            return 210

        if table2Version == 203 and indicatorOfParameter == 209:
            return 209

        if table2Version == 203 and indicatorOfParameter == 208:
            return 208

        if table2Version == 203 and indicatorOfParameter == 207:
            return 207

        if table2Version == 203 and indicatorOfParameter == 206:
            return 206

        if table2Version == 203 and indicatorOfParameter == 205:
            return 205

        if table2Version == 203 and indicatorOfParameter == 204:
            return 204

        if table2Version == 203 and indicatorOfParameter == 203:
            return 203

        if table2Version == 203 and indicatorOfParameter == 202:
            return 202

        if table2Version == 203 and indicatorOfParameter == 201:
            return 201

        if table2Version == 203 and indicatorOfParameter == 200:
            return 200

        if table2Version == 203 and indicatorOfParameter == 199:
            return 199

        if table2Version == 203 and indicatorOfParameter == 198:
            return 198

        if table2Version == 203 and indicatorOfParameter == 197:
            return 197

        if table2Version == 203 and indicatorOfParameter == 196:
            return 196

        if table2Version == 203 and indicatorOfParameter == 195:
            return 195

        if table2Version == 203 and indicatorOfParameter == 194:
            return 194

        if table2Version == 203 and indicatorOfParameter == 193:
            return 193

        if table2Version == 203 and indicatorOfParameter == 192:
            return 192

        if table2Version == 203 and indicatorOfParameter == 191:
            return 191

        if table2Version == 203 and indicatorOfParameter == 190:
            return 190

        if table2Version == 203 and indicatorOfParameter == 189:
            return 189

        if table2Version == 203 and indicatorOfParameter == 188:
            return 188

        if table2Version == 203 and indicatorOfParameter == 187:
            return 187

        if table2Version == 203 and indicatorOfParameter == 186:
            return 186

        if table2Version == 203 and indicatorOfParameter == 185:
            return 185

        if table2Version == 203 and indicatorOfParameter == 184:
            return 184

        if table2Version == 203 and indicatorOfParameter == 183:
            return 183

        if table2Version == 203 and indicatorOfParameter == 182:
            return 182

        if table2Version == 203 and indicatorOfParameter == 181:
            return 181

        if table2Version == 203 and indicatorOfParameter == 180:
            return 180

        if table2Version == 203 and indicatorOfParameter == 179:
            return 179

        if table2Version == 203 and indicatorOfParameter == 178:
            return 178

        if table2Version == 203 and indicatorOfParameter == 177:
            return 177

        if table2Version == 203 and indicatorOfParameter == 176:
            return 176

        if table2Version == 203 and indicatorOfParameter == 175:
            return 175

        if table2Version == 203 and indicatorOfParameter == 174:
            return 174

        if table2Version == 203 and indicatorOfParameter == 173:
            return 173

        if table2Version == 203 and indicatorOfParameter == 172:
            return 172

        if table2Version == 203 and indicatorOfParameter == 171:
            return 171

        if table2Version == 203 and indicatorOfParameter == 170:
            return 170

        if table2Version == 203 and indicatorOfParameter == 169:
            return 169

        if table2Version == 203 and indicatorOfParameter == 168:
            return 168

        if table2Version == 203 and indicatorOfParameter == 167:
            return 167

        if table2Version == 203 and indicatorOfParameter == 166:
            return 166

        if table2Version == 203 and indicatorOfParameter == 165:
            return 165

        if table2Version == 203 and indicatorOfParameter == 164:
            return 164

        if table2Version == 203 and indicatorOfParameter == 163:
            return 163

        if table2Version == 203 and indicatorOfParameter == 161:
            return 161

        if table2Version == 203 and indicatorOfParameter == 159:
            return 159

        if table2Version == 203 and indicatorOfParameter == 158:
            return 158

        if table2Version == 203 and indicatorOfParameter == 157:
            return 157

        if table2Version == 203 and indicatorOfParameter == 156:
            return 156

        if table2Version == 203 and indicatorOfParameter == 155:
            return 155

        if table2Version == 203 and indicatorOfParameter == 154:
            return 154

        if table2Version == 203 and indicatorOfParameter == 153:
            return 153

        if table2Version == 203 and indicatorOfParameter == 152:
            return 152

        if table2Version == 203 and indicatorOfParameter == 151:
            return 151

        if table2Version == 203 and indicatorOfParameter == 150:
            return 150

        if table2Version == 203 and indicatorOfParameter == 149:
            return 149

        if table2Version == 203 and indicatorOfParameter == 148:
            return 148

        if table2Version == 203 and indicatorOfParameter == 147:
            return 147

        if table2Version == 203 and indicatorOfParameter == 146:
            return 146

        if table2Version == 203 and indicatorOfParameter == 145:
            return 145

        if table2Version == 203 and indicatorOfParameter == 144:
            return 144

        if table2Version == 203 and indicatorOfParameter == 143:
            return 143

        if table2Version == 203 and indicatorOfParameter == 142:
            return 142

        if table2Version == 203 and indicatorOfParameter == 141:
            return 141

        if table2Version == 203 and indicatorOfParameter == 134:
            return 134

        if table2Version == 203 and indicatorOfParameter == 133:
            return 133

        if table2Version == 203 and indicatorOfParameter == 132:
            return 132

        if table2Version == 203 and indicatorOfParameter == 131:
            return 131

        if table2Version == 203 and indicatorOfParameter == 130:
            return 130

        if table2Version == 203 and indicatorOfParameter == 129:
            return 129

        if table2Version == 203 and indicatorOfParameter == 128:
            return 128

        if table2Version == 203 and indicatorOfParameter == 126:
            return 126

        if table2Version == 203 and indicatorOfParameter == 122:
            return 122

        if table2Version == 203 and indicatorOfParameter == 121:
            return 121

        if table2Version == 203 and indicatorOfParameter == 120:
            return 120

        if table2Version == 203 and indicatorOfParameter == 119:
            return 119

        if table2Version == 203 and indicatorOfParameter == 118:
            return 118

        if table2Version == 203 and indicatorOfParameter == 117:
            return 117

        if table2Version == 203 and indicatorOfParameter == 116:
            return 116

        if table2Version == 203 and indicatorOfParameter == 115:
            return 115

        if table2Version == 203 and indicatorOfParameter == 114:
            return 114

        if table2Version == 203 and indicatorOfParameter == 113:
            return 113

        if table2Version == 203 and indicatorOfParameter == 112:
            return 112

        if table2Version == 203 and indicatorOfParameter == 111:
            return 111

        if table2Version == 203 and indicatorOfParameter == 110:
            return 110

        if table2Version == 203 and indicatorOfParameter == 109:
            return 109

        if table2Version == 203 and indicatorOfParameter == 108:
            return 108

        if table2Version == 203 and indicatorOfParameter == 107:
            return 107

        if table2Version == 203 and indicatorOfParameter == 106:
            return 106

        if table2Version == 203 and indicatorOfParameter == 105:
            return 105

        if table2Version == 203 and indicatorOfParameter == 104:
            return 104

        if table2Version == 203 and indicatorOfParameter == 103:
            return 103

        if table2Version == 203 and indicatorOfParameter == 102:
            return 102

        if table2Version == 203 and indicatorOfParameter == 101:
            return 101

        if table2Version == 203 and indicatorOfParameter == 100:
            return 100

        if table2Version == 203 and indicatorOfParameter == 99:
            return 99

        if table2Version == 203 and indicatorOfParameter == 96:
            return 96

        if table2Version == 203 and indicatorOfParameter == 95:
            return 95

        if table2Version == 203 and indicatorOfParameter == 91:
            return 91

        if table2Version == 203 and indicatorOfParameter == 89:
            return 89

        if table2Version == 203 and indicatorOfParameter == 80:
            return 80

        if table2Version == 203 and indicatorOfParameter == 79:
            return 79

        if table2Version == 203 and indicatorOfParameter == 78:
            return 78

        if table2Version == 203 and indicatorOfParameter == 77:
            return 77

        if table2Version == 203 and indicatorOfParameter == 75:
            return 75

        if table2Version == 203 and indicatorOfParameter == 74:
            return 74

        if table2Version == 203 and indicatorOfParameter == 73:
            return 73

        if table2Version == 203 and indicatorOfParameter == 72:
            return 72

        if table2Version == 203 and indicatorOfParameter == 71:
            return 71

        if table2Version == 203 and indicatorOfParameter == 70:
            return 70

        if table2Version == 203 and indicatorOfParameter == 69:
            return 69

        if table2Version == 203 and indicatorOfParameter == 68:
            return 68

        if table2Version == 203 and indicatorOfParameter == 63:
            return 63

        if table2Version == 203 and indicatorOfParameter == 62:
            return 62

        if table2Version == 203 and indicatorOfParameter == 60:
            return 60

        if table2Version == 203 and indicatorOfParameter == 59:
            return 59

        if table2Version == 203 and indicatorOfParameter == 58:
            return 58

        if table2Version == 203 and indicatorOfParameter == 57:
            return 57

        if table2Version == 203 and indicatorOfParameter == 56:
            return 56

        if table2Version == 203 and indicatorOfParameter == 55:
            return 55

        if table2Version == 203 and indicatorOfParameter == 54:
            return 54

        if table2Version == 203 and indicatorOfParameter == 53:
            return 53

        if table2Version == 203 and indicatorOfParameter == 52:
            return 52

        if table2Version == 203 and indicatorOfParameter == 51:
            return 51

        if table2Version == 203 and indicatorOfParameter == 50:
            return 50

        if table2Version == 203 and indicatorOfParameter == 47:
            return 47

        if table2Version == 203 and indicatorOfParameter == 44:
            return 44

        if table2Version == 203 and indicatorOfParameter == 43:
            return 43

        if table2Version == 203 and indicatorOfParameter == 40:
            return 40

        if table2Version == 203 and indicatorOfParameter == 39:
            return 39

        if table2Version == 203 and indicatorOfParameter == 38:
            return 38

        if table2Version == 203 and indicatorOfParameter == 31:
            return 31

        if table2Version == 203 and indicatorOfParameter == 28:
            return 28

        if table2Version == 203 and indicatorOfParameter == 27:
            return 27

        if table2Version == 203 and indicatorOfParameter == 24:
            return 24

        if table2Version == 203 and indicatorOfParameter == 23:
            return 23

        if table2Version == 203 and indicatorOfParameter == 22:
            return 22

        if table2Version == 203 and indicatorOfParameter == 21:
            return 21

        if table2Version == 203 and indicatorOfParameter == 20:
            return 20

        if table2Version == 203 and indicatorOfParameter == 19:
            return 19

        if table2Version == 203 and indicatorOfParameter == 18:
            return 18

        if table2Version == 203 and indicatorOfParameter == 15:
            return 15

        if table2Version == 203 and indicatorOfParameter == 13:
            return 13

        if table2Version == 203 and indicatorOfParameter == 12:
            return 12

        if table2Version == 203 and indicatorOfParameter == 10:
            return 10

        if table2Version == 203 and indicatorOfParameter == 9:
            return 9

        if table2Version == 203 and indicatorOfParameter == 8:
            return 8

        if table2Version == 203 and indicatorOfParameter == 4:
            return 4

        if table2Version == 203 and indicatorOfParameter == 3:
            return 3

        if table2Version == 203 and indicatorOfParameter == 2:
            return 2

        if table2Version == 203 and indicatorOfParameter == 1:
            return 1

    return wrapped
